@@ -136,7 +136,9 @@ DatadogIAMUser(stack, "TestUser",
 
 ```python
 # Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
-DatadogIntegration(self, "DataDogIntegration",
+from nomadblacky.cdk_datadog_resources import DatadogIntegrationAWS
+
+DatadogIntegrationAWS(self, "DataDogIntegration",
     datadog_credentials={
         "api_key": "DATADOG_API_KEY",
         "application_key": "DATADOG_APP_KEY"
